@@ -98,8 +98,7 @@ protected:
   // so none of the auto-displaying update routines need to display.
 
   // SIGWINCH handling
-  struct sigaction *osigactp, nsigact;
-  sigset_t *oblockedp, sigwinchset;
+  void sigwinch_mask(int how);
   void setupsigwinch();
 
   static baselist *signallist;
