@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -65,5 +65,5 @@ cu_filename(int argc, void **argv)
 {
 	const char *filename = argv[0];
 
-	unlink(filename);
+	(void)unlink(filename);
 }
