@@ -3,7 +3,7 @@
  * main.h - external definitions for this program
  *
  * Copyright © 1995 Ian Jackson <ian@chiark.greenend.org.uk>
- * Copyright © 2006,2008-2014 Guillem Jover <guillem@debian.org>
+ * Copyright © 2006, 2008-2015 Guillem Jover <guillem@debian.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,10 +31,15 @@ struct filenamenode_queue;
 struct filenamenode;
 
 enum pkg_istobe {
+	/** Package is to be left in a normal state. */
 	PKG_ISTOBE_NORMAL,
+	/** Package is to be removed. */
 	PKG_ISTOBE_REMOVE,
+	/** Package is to be installed, configured or triggered. */
 	PKG_ISTOBE_INSTALLNEW,
+	/** Package is to be deconfigured. */
 	PKG_ISTOBE_DECONFIGURE,
+	/** Package is to be checked for Pre-Depends satisfiability. */
 	PKG_ISTOBE_PREINSTALL,
 };
 
@@ -236,10 +241,7 @@ bool force_breaks(struct deppossi *possi);
 bool force_depends(struct deppossi *possi);
 bool force_conflicts(struct deppossi *possi);
 void conffile_mark_obsolete(struct pkginfo *pkg, struct filenamenode *namenode);
-void oldconffsetflags(const struct conffile *searchconff);
-void ensure_pathname_nonexisting(const char *pathname);
-int secure_unlink(const char *pathname);
-int secure_unlink_statted(const char *pathname, const struct stat *stab);
+void pkg_conffiles_mark_old(struct pkginfo *pkg);
 void checkpath(void);
 
 struct filenamenode *namenodetouse(struct filenamenode *namenode,
@@ -270,6 +272,12 @@ bool dir_has_conffiles(struct filenamenode *namenode, struct pkginfo *pkg);
 
 void log_action(const char *action, struct pkginfo *pkg, struct pkgbin *pkgbin);
 
+/* From selinux.c */
+
+void dpkg_selabel_load(void);
+void dpkg_selabel_set_context(const char *matchpath, const char *path, mode_t mode);
+void dpkg_selabel_close(void);
+
 /* from trigproc.c */
 
 enum trigproc_type {
