@@ -63,11 +63,6 @@ static int opt_skip_auto = 0;
 static int opt_verbose = 0;
 static int opt_force = 0;
 
-#define MAX_OPTS 128
-#define PUSH_OPT(a) if (nb_opts < MAX_OPTS) pass_opts[nb_opts++] = a;
-static char *pass_opts[MAX_OPTS];
-static int nb_opts = 0;
-
 #define ALT_TMP_EXT ".dpkg-tmp"
 
 /*
@@ -420,42 +415,6 @@ spawn(const char *prog, const char *args[])
 	return status;
 }
 
-static void DPKG_ATTR_SENTINEL
-subcall(const char *prog, ...)
-{
-	va_list args;
-	const char **cmd;
-	int res, i, j, count;
-
-	/* Count the arguments */
-	va_start(args, prog);
-	count = 0;
-	while (va_arg(args, char *))
-		count++;
-	va_end(args);
-
-	/* Prepare table for all parameters */
-	cmd = xmalloc(sizeof(*cmd) * (nb_opts + count + 2));
-	i = 0;
-	cmd[i++] = prog;
-	for (j = 0; j < nb_opts; j++)
-		cmd[i++] = pass_opts[j];
-	va_start(args, prog);
-	for (j = 0; j < count; j++)
-		cmd[i++] = va_arg(args, char *);
-	va_end(args);
-	cmd[i++] = NULL;
-
-	/* Run the command */
-	res = spawn(prog, cmd);
-	free(cmd);
-	if (WIFEXITED(res) && WEXITSTATUS(res) == 0)
-		return;
-	if (WIFEXITED(res))
-		exit(WEXITSTATUS(res));
-	exit(128);
-}
-
 static bool
 rename_mv(const char *src, const char *dst)
 {
@@ -1533,12 +1492,20 @@ alternative_display_user(struct alternative *a)
 	struct slave_link *sl;
 
 	pr("%s - %s", a->master_name, alternative_status_describe(a->status));
+	fs = alternative_get_best(a);
+	if (fs)
+		pr(_("  link best version is %s"), fs->master_file);
+	else
+		pr(_("  link best version not available"));
 	current = alternative_get_current(a);
 	if (current) {
 		pr(_("  link currently points to %s"), current);
 	} else {
 		pr(_("  link currently absent"));
 	}
+	pr(_("  link %s is %s"), a->master_name, a->master_link);
+	for (sl = a->slaves; sl; sl = sl->next)
+		pr(_("  slave %s is %s"), sl->name, sl->link);
 
 	for (fs = a->choices; fs; fs = fs->next) {
 		pr(_("%s - priority %d"), fs->master_file, fs->priority);
@@ -1548,12 +1515,6 @@ alternative_display_user(struct alternative *a)
 				   fileset_get_slave(fs, sl->name));
 		}
 	}
-
-	fs = alternative_get_best(a);
-	if (fs)
-		pr(_("Current 'best' version is '%s'."), fs->master_file);
-	else
-		pr(_("No versions available."));
 }
 
 static void
@@ -1582,7 +1543,7 @@ alternative_print_choice(struct alternative *a, enum alternative_status status,
 	   fs->master_file, fs->priority, alternative_status_describe(status));
 }
 
-static const char *
+static char *
 alternative_select_choice(struct alternative *a)
 {
 	const char *current;
@@ -1622,7 +1583,7 @@ alternative_select_choice(struct alternative *a)
 		}
 		selection[strlen(selection) - 1] = '\0';
 		if (strlen(selection) == 0)
-			return current;
+			return xstrdup(current);
 		errno = 0;
 		idx = strtol(selection, &ret, 10);
 		if (idx < 0 || errno != 0)
@@ -1651,18 +1612,28 @@ alternative_select_choice(struct alternative *a)
 	}
 }
 
-static void
-alternative_config_all(void)
+static char *
+alternative_config(struct alternative *a, const char *current_choice)
 {
-	struct dirent **table;
-	int i, count;
+	char *new_choice = NULL;
 
-	count = altdb_get_namelist(&table);
-	for (i = 0; i < count; i++) {
-		subcall(prog_path, "--config", table[i]->d_name, NULL);
-		printf("\n");
+	if (alternative_choices_count(a) == 0) {
+		pr(_("There is no program which provides %s."),
+		   a->master_name);
+		pr(_("Nothing to configure."));
+	} else if (opt_skip_auto && a->status == ALT_ST_AUTO) {
+		alternative_display_user(a);
+	} else if (alternative_choices_count(a) == 1 &&
+	           a->status == ALT_ST_AUTO &&
+	           current_choice != NULL) {
+		pr(_("There is only one alternative in link group %s (providing %s): %s"),
+		   a->master_name, a->master_link, current_choice);
+		pr(_("Nothing to configure."));
+	} else {
+		new_choice = alternative_select_choice(a);
 	}
-	altdb_free_namelist(table, count);
+
+	return new_choice;
 }
 
 static void
@@ -1840,7 +1811,7 @@ alternative_prepare_install(struct alternative *a, const char *choice)
 }
 
 static void
-alternative_remove(struct alternative *a)
+alternative_remove_files(struct alternative *a)
 {
 	struct slave_link *sl;
 
@@ -1863,6 +1834,37 @@ alternative_remove(struct alternative *a)
 	checked_rm_args("%s/%s", admdir, a->master_name);
 }
 
+static const char *
+alternative_remove(struct alternative *a, const char *current_choice,
+                   const char *path)
+{
+	const char *new_choice = NULL;
+
+	if (alternative_has_choice(a, path))
+		alternative_remove_choice(a, path);
+	else
+		verbose(_("alternative %s for %s not registered; not removing"),
+		        path, a->master_name);
+
+	if (current_choice && strcmp(current_choice, path) == 0) {
+		struct fileset *best;
+
+		/* Current choice is removed. */
+		if (a->status == ALT_ST_MANUAL) {
+			/* And it was manual, switch to auto. */
+			info(_("removing manually selected alternative "
+			       "- switching %s to auto mode"),
+			     a->master_name);
+			alternative_set_status(a, ALT_ST_AUTO);
+		}
+		best = alternative_get_best(a);
+		if (best)
+			new_choice = best->master_file;
+	}
+
+	return new_choice;
+}
+
 static bool
 alternative_has_broken_slave(struct slave_link *sl, struct fileset *fs)
 {
@@ -2062,6 +2064,36 @@ alternative_map_free(struct alternative_map *am)
 	}
 }
 
+static const char *
+alternative_set_manual(struct alternative *a, const char *path)
+{
+	const char *new_choice = NULL;
+
+	if (alternative_has_choice(a, path))
+		new_choice = path;
+	else
+		error(_("alternative %s for %s not registered; "
+		        "not setting"), path, a->master_name);
+	alternative_set_status(a, ALT_ST_MANUAL);
+
+	return new_choice;
+}
+
+static const char *
+alternative_set_auto(struct alternative *a)
+{
+	const char *new_choice = NULL;
+
+	alternative_set_status(a, ALT_ST_AUTO);
+	if (alternative_choices_count(a) == 0)
+		pr(_("There is no program which provides %s."),
+		   a->master_name);
+	else
+		new_choice = alternative_get_best(a)->master_file;
+
+	return new_choice;
+}
+
 static const char *
 get_argv_string(int argc, char **argv)
 {
@@ -2087,129 +2119,6 @@ get_argv_string(int argc, char **argv)
 	return string;
 }
 
-static void
-alternative_get_selections(void)
-{
-	struct alternative_map *alt_map_obj;
-	struct alternative_map *am;
-
-	alt_map_obj = alternative_map_new(NULL, NULL);
-	alternative_map_load_names(alt_map_obj);
-
-	for (am = alt_map_obj; am && am->item; am = am->next) {
-		const char *current;
-
-		current = alternative_get_current(am->item);
-		printf("%-30s %-8s %s\n", am->key,
-		       alternative_status_string(am->item->status),
-		       current ? current : "");
-	}
-
-	alternative_map_free(alt_map_obj);
-}
-
-static void
-alternative_set_selection(struct alternative_map *all, const char *name,
-                          const char *status, const char *choice)
-{
-	struct alternative *a;
-
-	debug("set_selection(%s, %s, %s)", name, status, choice);
-	a = alternative_map_find(all, name);
-	if (a) {
-		char *cmd;
-
-		if (strcmp(status, "auto") == 0) {
-			xasprintf(&cmd, "%s --auto %s", PROGNAME, name);
-			pr(_("Call %s."), cmd);
-			free(cmd);
-			subcall(prog_path, "--auto", name, NULL);
-		} else if (alternative_has_choice(a, choice)) {
-			xasprintf(&cmd, "%s --set %s %s", PROGNAME,
-			          name, choice);
-			pr(_("Call %s."), cmd);
-			free(cmd);
-			subcall(prog_path, "--set", name, choice, NULL);
-		} else {
-			pr(_("Alternative %s unchanged because choice "
-			     "%s is not available."), name, choice);
-		}
-	} else {
-		pr(_("Skip unknown alternative %s."), name);
-	}
-}
-
-static void
-alternative_set_selections(FILE *input, const char *desc)
-{
-	struct alternative_map *alt_map_obj;
-
-	alt_map_obj = alternative_map_new(NULL, NULL);
-	alternative_map_load_names(alt_map_obj);
-
-	for (;;) {
-		char line[1024], *res, *name, *status, *choice;
-		size_t len, i;
-
-		errno = 0;
-		/* Can't use scanf("%s %s %s") because choice can
-		 * contain a space */
-		res = fgets(line, sizeof(line), input);
-		if (res == NULL && errno) {
-			syserr(_("read error in %.250s"), desc);
-		} else if (res == NULL) {
-			break;
-		}
-		len = strlen(line);
-		if (len == 0 || line[len - 1] != '\n') {
-			error(_("line too long or not terminated while "
-			        "trying to read %s"), desc);
-		}
-		line[len - 1] = '\0';
-		len--;
-
-		/* Delimit name string in line */
-		i = 0;
-		name = line;
-		while (i < len && !isblank(line[i]))
-			i++;
-		if (i >= len) {
-			printf("[%s %s] ", PROGNAME, "--set-selections");
-			pr(_("Skip invalid line: %s"), line);
-			continue;
-		}
-		line[i++] = '\0';
-		while (i < len && isblank(line[i]))
-			i++;
-
-		/* Delimit status string in line */
-		status = line + i;
-		while (i < len && !isblank(line[i]))
-			i++;
-		if (i >= len) {
-			printf("[%s %s] ", PROGNAME, "--set-selections");
-			pr(_("Skip invalid line: %s"), line);
-			continue;
-		}
-		line[i++] = '\0';
-		while (i < len && isblank(line[i]))
-			i++;
-
-		/* Delimit choice string in the line */
-		if (i >= len) {
-			printf("[%s %s] ", PROGNAME, "--set-selections");
-			pr(_("Skip invalid line: %s"), line);
-			continue;
-		}
-		choice = line + i;
-
-		printf("[%s %s] ", PROGNAME, "--set-selections");
-		alternative_set_selection(alt_map_obj, name, status, choice);
-	}
-
-	alternative_map_free(alt_map_obj);
-}
-
 static void
 alternative_select_mode(struct alternative *a, const char *current_choice)
 {
@@ -2322,7 +2231,7 @@ alternative_update(struct alternative *a,
 	/* No choice left, remove everything. */
 	if (!alternative_choices_count(a)) {
 		log_msg("link group %s fully removed", a->master_name);
-		alternative_remove(a);
+		alternative_remove_files(a);
 		return;
 	}
 
@@ -2378,6 +2287,157 @@ alternative_update(struct alternative *a,
 	alternative_commit(a);
 }
 
+static void
+alternative_config_all(void)
+{
+	struct alternative_map *alt_map_obj;
+	struct alternative_map *am;
+
+	alt_map_obj = alternative_map_new(NULL, NULL);
+	alternative_map_load_names(alt_map_obj);
+
+	for (am = alt_map_obj; am && am->item; am = am->next) {
+		const char *current_choice;
+		char *new_choice;
+
+		current_choice = alternative_get_current(am->item);
+		alternative_select_mode(am->item, current_choice);
+
+		new_choice = alternative_config(am->item, current_choice);
+
+		alternative_update(am->item, current_choice, new_choice);
+
+		free(new_choice);
+	}
+
+	alternative_map_free(alt_map_obj);
+}
+
+static void
+alternative_get_selections(void)
+{
+	struct alternative_map *alt_map_obj;
+	struct alternative_map *am;
+
+	alt_map_obj = alternative_map_new(NULL, NULL);
+	alternative_map_load_names(alt_map_obj);
+
+	for (am = alt_map_obj; am && am->item; am = am->next) {
+		const char *current;
+
+		current = alternative_get_current(am->item);
+		printf("%-30s %-8s %s\n", am->key,
+		       alternative_status_string(am->item->status),
+		       current ? current : "");
+	}
+
+	alternative_map_free(alt_map_obj);
+}
+
+static void
+alternative_set_selection(struct alternative_map *all, const char *name,
+                          const char *status, const char *choice)
+{
+	struct alternative *a;
+
+	debug("set_selection(%s, %s, %s)", name, status, choice);
+	a = alternative_map_find(all, name);
+	if (a) {
+		const char *new_choice = NULL;
+
+		if (strcmp(status, "auto") == 0) {
+			new_choice = alternative_set_auto(a);
+		} else if (alternative_has_choice(a, choice)) {
+			new_choice = alternative_set_manual(a, choice);
+		} else {
+			pr(_("Alternative %s unchanged because choice "
+			     "%s is not available."), name, choice);
+		}
+
+		if (new_choice) {
+			const char *current_choice;
+
+			current_choice = alternative_get_current(a);
+			alternative_select_mode(a, current_choice);
+
+			alternative_update(a, current_choice, new_choice);
+		}
+	} else {
+		pr(_("Skip unknown alternative %s."), name);
+	}
+}
+
+static void
+alternative_set_selections(FILE *input, const char *desc)
+{
+	struct alternative_map *alt_map_obj;
+
+	alt_map_obj = alternative_map_new(NULL, NULL);
+	alternative_map_load_names(alt_map_obj);
+
+	for (;;) {
+		char line[1024], *res, *name, *status, *choice;
+		size_t len, i;
+
+		errno = 0;
+		/* Can't use scanf("%s %s %s") because choice can
+		 * contain a space */
+		res = fgets(line, sizeof(line), input);
+		if (res == NULL && errno) {
+			syserr(_("read error in %.250s"), desc);
+		} else if (res == NULL) {
+			break;
+		}
+		len = strlen(line);
+		if (len == 0 || line[len - 1] != '\n') {
+			error(_("line too long or not terminated while "
+			        "trying to read %s"), desc);
+		}
+		line[len - 1] = '\0';
+		len--;
+
+		/* Delimit name string in line */
+		i = 0;
+		name = line;
+		while (i < len && !isblank(line[i]))
+			i++;
+		if (i >= len) {
+			printf("[%s %s] ", PROGNAME, "--set-selections");
+			pr(_("Skip invalid line: %s"), line);
+			continue;
+		}
+		line[i++] = '\0';
+		while (i < len && isblank(line[i]))
+			i++;
+
+		/* Delimit status string in line */
+		status = line + i;
+		while (i < len && !isblank(line[i]))
+			i++;
+		if (i >= len) {
+			printf("[%s %s] ", PROGNAME, "--set-selections");
+			pr(_("Skip invalid line: %s"), line);
+			continue;
+		}
+		line[i++] = '\0';
+		while (i < len && isblank(line[i]))
+			i++;
+
+		/* Delimit choice string in the line */
+		if (i >= len) {
+			printf("[%s %s] ", PROGNAME, "--set-selections");
+			pr(_("Skip invalid line: %s"), line);
+			continue;
+		}
+		choice = line + i;
+
+		printf("[%s %s] ", PROGNAME, "--set-selections");
+		alternative_set_selection(alt_map_obj, name, status, choice);
+	}
+
+	alternative_map_free(alt_map_obj);
+}
+
 static void
 alternative_check_name(const char *name)
 {
@@ -2538,10 +2598,8 @@ main(int argc, char **argv)
 			exit(0);
 		} else if (strcmp("--verbose", argv[i]) == 0) {
 			opt_verbose++;
-			PUSH_OPT(argv[i]);
 		} else if (strcmp("--quiet", argv[i]) == 0) {
 			opt_verbose--;
-			PUSH_OPT(argv[i]);
 		} else if (strcmp("--install", argv[i]) == 0) {
 			char *prio_str, *prio_end;
 			long prio;
@@ -2641,30 +2699,22 @@ main(int argc, char **argv)
 		} else if (strcmp("--log", argv[i]) == 0) {
 			if (MISSING_ARGS(1))
 				badusage(_("--%s needs a <file> argument"), "log");
-			PUSH_OPT(argv[i]);
-			PUSH_OPT(argv[i + 1]);
 			log_file = argv[i + 1];
 			i++;
 		} else if (strcmp("--altdir", argv[i]) == 0) {
 			if (MISSING_ARGS(1))
 				badusage(_("--%s needs a <directory> argument"), "log");
-			PUSH_OPT(argv[i]);
-			PUSH_OPT(argv[i + 1]);
 			altdir = argv[i + 1];
 			i++;
 		} else if (strcmp("--admindir", argv[i]) == 0) {
 			if (MISSING_ARGS(1))
 				badusage(_("--%s needs a <directory> argument"), "log");
-			PUSH_OPT(argv[i]);
-			PUSH_OPT(argv[i + 1]);
 			admdir = argv[i + 1];
 			i++;
 		} else if (strcmp("--skip-auto", argv[i]) == 0) {
 			opt_skip_auto = 1;
-			PUSH_OPT(argv[i]);
 		} else if (strcmp("--force", argv[i]) == 0) {
 			opt_force = 1;
-			PUSH_OPT(argv[i]);
 		} else {
 			badusage(_("unknown option '%s'"), argv[i]);
 		}
@@ -2703,6 +2753,7 @@ main(int argc, char **argv)
 
 	/* Handle actions. */
 	if (strcmp(action, "all") == 0) {
+		log_msg("run with %s", get_argv_string(argc, argv));
 		alternative_config_all();
 		exit(0);
 	} else if (strcmp(action, "get-selections") == 0) {
@@ -2729,56 +2780,13 @@ main(int argc, char **argv)
 	alternative_select_mode(a, current_choice);
 
 	if (strcmp(action, "set") == 0) {
-		if (alternative_has_choice(a, path))
-			new_choice = path;
-		else
-			error(_("alternative %s for %s not registered; "
-			        "not setting"), path, a->master_name);
-		alternative_set_status(a, ALT_ST_MANUAL);
+		new_choice = alternative_set_manual(a, path);
 	} else if (strcmp(action, "auto") == 0) {
-		alternative_set_status(a, ALT_ST_AUTO);
-		if (alternative_choices_count(a) == 0)
-			pr(_("There is no program which provides %s."),
-			   a->master_name);
-		else
-			new_choice = alternative_get_best(a)->master_file;
+		new_choice = alternative_set_auto(a);
 	} else if (strcmp(action, "config") == 0) {
-		if (alternative_choices_count(a) == 0) {
-			pr(_("There is no program which provides %s."),
-			   a->master_name);
-			pr(_("Nothing to configure."));
-		} else if (opt_skip_auto && a->status == ALT_ST_AUTO) {
-			alternative_display_user(a);
-		} else if (alternative_choices_count(a) == 1 &&
-		           a->status == ALT_ST_AUTO &&
-		           current_choice != NULL) {
-			pr(_("There is only one alternative in link group %s (providing %s): %s"),
-			   a->master_name, a->master_link, current_choice);
-			pr(_("Nothing to configure."));
-		} else {
-			new_choice = alternative_select_choice(a);
-		}
+		new_choice = alternative_config(a, current_choice);
 	} else if (strcmp(action, "remove") == 0) {
-		if (alternative_has_choice(a, path))
-			alternative_remove_choice(a, path);
-		else
-			verbose(_("alternative %s for %s not registered; not "
-			          "removing"), path, a->master_name);
-		if (current_choice && strcmp(current_choice, path) == 0) {
-			struct fileset *best;
-
-			/* Current choice is removed. */
-			if (a->status == ALT_ST_MANUAL) {
-				/* And it was manual, switch to auto. */
-				info(_("removing manually selected alternative "
-				       "- switching %s to auto mode"),
-				     a->master_name);
-				alternative_set_status(a, ALT_ST_AUTO);
-			}
-			best = alternative_get_best(a);
-			if (best)
-				new_choice = best->master_file;
-		}
+		new_choice = alternative_remove(a, current_choice, path);
 	} else if (strcmp(action, "remove-all") == 0) {
 		alternative_choices_free(a);
 	} else if (strcmp(action, "install") == 0) {
